@@ -8,6 +8,7 @@ import numpy as np
 import pandas as pd
 import rdt
 from faker import Faker
+from xeger import Xeger
 
 from sdv.constraints.base import Constraint
 from sdv.metadata.errors import MetadataError, MetadataNotFittedError
@@ -24,6 +25,8 @@ class Table:
     and the constraints that affect this data.
 
     Args:
+        name (str):
+            Name of this table. Optional.
         field_names (list[str]):
             List of names of the fields that need to be modeled
             and included in the generated output data. Any additional
@@ -68,8 +71,18 @@ class Table:
             fitted using the same arguments when the same Table is used
             to fit different model instances on different slices of the
             same table.
-        name (str):
-            Name of this table. Optional.
+        sequence_index (str):
+            Name of the column that acts as the order index of each
+            sequence. The sequence index column can be of any type that can
+            be sorted, such as integer values or datetimes.
+        entity_columns (list[str]):
+            Names of the columns which identify different time series
+            sequences. These will be used to group the data in separated
+            training examples.
+        context_columns (list[str]):
+            The columns in the dataframe which are constant within each
+            group/entity. These columns will be provided at sampling time
+            (i.e. the samples will be conditioned on the context variables).
     """
 
     _hyper_transformer = None
@@ -87,7 +100,7 @@ class Table:
         'one_hot_encoding': rdt.transformers.OneHotEncodingTransformer,
         'label_encoding': rdt.transformers.LabelEncodingTransformer,
         'boolean': rdt.transformers.BooleanTransformer,
-        'datetime': rdt.transformers.DatetimeTransformer,
+        'datetime': rdt.transformers.DatetimeTransformer(strip_constant=True),
     }
     _DTYPE_TRANSFORMERS = {
         'i': 'integer',
@@ -164,7 +177,8 @@ class Table:
 
     def __init__(self, name=None, field_names=None, field_types=None, field_transformers=None,
                  anonymize_fields=None, primary_key=None, constraints=None,
-                 dtype_transformers=None, model_kwargs=None):
+                 dtype_transformers=None, model_kwargs=None, sequence_index=None,
+                 entity_columns=None, context_columns=None):
         self.name = name
         self._field_names = field_names
         self._field_types = field_types or {}
@@ -173,6 +187,9 @@ class Table:
         self._model_kwargs = model_kwargs or {}
 
         self._primary_key = primary_key
+        self._sequence_index = sequence_index
+        self._entity_columns = entity_columns or []
+        self._context_columns = context_columns or []
         self._constraints = constraints or []
         self._dtype_transformers = self._DTYPE_TRANSFORMERS.copy()
         if dtype_transformers:
@@ -304,6 +321,10 @@ class Table:
             transformer_template = field_metadata.get('transformer')
             if transformer_template is None:
                 transformer_template = self._dtype_transformers[np.dtype(dtype).kind]
+                if transformer_template is None:
+                    # Skip this dtype
+                    continue
+
                 field_metadata['transformer'] = transformer_template
 
             if isinstance(transformer_template, str):
@@ -385,33 +406,36 @@ class Table:
 
         return field_subtype
 
-    def set_primary_key(self, field_name):
+    def set_primary_key(self, primary_key):
         """Set the primary key of this table.
 
         The field must exist and either be an integer or categorical field.
 
         Args:
-            field_name (str):
-                Name of the field to be used as the new primary key.
+            primary_key (str or list):
+                Name of the field(s) to be used as the new primary key.
 
         Raises:
             ValueError:
                 If the table or the field do not exist or if the field has an
                 invalid type or subtype.
         """
-        if field_name is not None:
-            if field_name not in self._fields_metadata:
-                raise ValueError('Field "{}" does not exist in this table'.format(field_name))
+        if primary_key is not None:
+            fields = primary_key if isinstance(primary_key, list) else [primary_key]
+            for field_name in fields:
+                if field_name not in self._fields_metadata:
+                    raise ValueError('Field "{}" does not exist in this table'.format(field_name))
 
-            field_metadata = self._fields_metadata[field_name]
-            field_subtype = self._get_key_subtype(field_metadata)
+                field_metadata = self._fields_metadata[field_name]
+                if field_metadata['type'] != 'id':
+                    field_subtype = self._get_key_subtype(field_metadata)
 
-            field_metadata.update({
-                'type': 'id',
-                'subtype': field_subtype
-            })
+                    field_metadata.update({
+                        'type': 'id',
+                        'subtype': field_subtype
+                    })
 
-        self._primary_key = field_name
+        self._primary_key = primary_key
 
     def _make_anonymization_mappings(self, data):
         mappings = {}
@@ -488,6 +512,31 @@ class Table:
         LOGGER.debug('Transforming table %s', self.name)
         return self._hyper_transformer.transform(data)
 
+    def _make_ids(self, name, field_metadata, length):
+        field_subtype = field_metadata.get('subtype', 'integer')
+        if field_subtype == 'string':
+            regex = field_metadata.get('regex', '[a-z][A-Z]+')
+            xeger = Xeger(limit=10)
+            values = {xeger.xeger(regex) for _ in range(length)}
+            for _ in range(10):
+                done = len(values)
+                if done >= length:
+                    break
+
+                remaining = length - done
+                generate = int(round((remaining / done) * length))
+                values.update({xeger.xeger(regex) for _ in range(generate)})
+
+            else:
+                msg = 'Unable to generate {} unique values for field {} regex "{}"'.format(
+                    length, name, regex
+                )
+                raise ValueError(msg)
+
+            return pd.Series(list(values)[:length])
+        else:
+            return pd.Series(np.arange(length))
+
     def reverse_transform(self, data):
         """Reverse the transformed data to the original format.
 
@@ -510,13 +559,13 @@ class Table:
         for name, dtype in self.get_dtypes(ids=True).items():
             field_metadata = fields[name]
             field_type = field_metadata['type']
-            if field_type != 'id':
-                field_data = reversed_data[name]
+            if field_type == 'id' and name not in reversed_data:
+                field_data = self._make_ids(name, field_metadata, len(reversed_data))
             elif field_metadata.get('pii', False):
                 faker = self._get_faker(field_metadata['pii_category'])
                 field_data = pd.Series([faker() for _ in range(len(reversed_data))])
             else:
-                field_data = pd.Series(np.arange(len(reversed_data)))
+                field_data = reversed_data[name]
 
             reversed_data[name] = field_data.dropna().astype(dtype)
 
@@ -557,6 +606,10 @@ class Table:
             ],
             'model_kwargs': copy.deepcopy(self._model_kwargs),
             'name': self.name,
+            'primary_key': self._primary_key,
+            'sequence_index': self._sequence_index,
+            'entity_columns': self._entity_columns,
+            'context_columns': self._context_columns,
         }
 
     def to_json(self, path):
@@ -583,6 +636,9 @@ class Table:
         instance._constraints = copy.deepcopy(metadata_dict.get('constraints', []))
         instance._model_kwargs = copy.deepcopy(metadata_dict.get('model_kwargs', {}))
         instance._primary_key = metadata_dict.get('primary_key')
+        instance._sequence_index = metadata_dict.get('sequence_index')
+        instance._entity_columns = metadata_dict.get('entity_columns')
+        instance._context_columns = metadata_dict.get('context_columns')
         instance.name = metadata_dict.get('name')
         return instance
 
